// 
// Module: CalPNResponse
// Author: Hassan Siddiqui
//
// Description: 
// Provides a clean interface to CAL response data.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: CalPNResponse.cc,v 1.2 2000/11/01 09:16:58 hsiddiqu Exp $

/* General */
#include <string>
#include <iostream.h>
#include <vector>

/* SAS-specific */
#include "Dal.h"
#include "CalServer.h"
#include "Redistribution.h"
#include "Tracer.h"

// Local classes
#include "CalPNResponse.h"

/*****************************
 *
 * class CalPNResponse
 *
 * Interface to CAL response data.
 *
 *****************************/


inline void CalPNResponse::init( unsigned line )
{
  
  PROC;

  /* Currently set state for default EPN settings */
  calServer.setInstrument(Xmm::EPN);
  calServer.state()->ccd()->set(EPNcam::CCD_1);
  // calServer.state()->node()->set(Xmm::PRIMARY_NODE);
  
  /* Get response information */
  CanonicalRedist * rmf = calServer.getAtom(rmf);

  errstr 
    << "CalPNResponse: response model appropriate for line " << line
    << Sas::message(Msg::App, Msg::Verbose);

  rmf->at(line);   // extract redist spectrum appl. at CCD line
  _rmf = rmf;
  
  ENDPROC;
}

/* Constructors */
/* Provides the entire range of 
 * redistribution available from the CAL */
CalPNResponse::CalPNResponse ( unsigned line, 
			       unsigned lowerPI,
			       unsigned nOutputChannels,
			       unsigned outputChannelWidth)
{
  init(line);
  createWithCalEbins(lowerPI, 
		     nOutputChannels, 
		     outputChannelWidth);
}  

/* Provides a restricted range */
CalPNResponse::CalPNResponse ( unsigned line,
			       unsigned lowerPI,
			       unsigned nOutputChannels,
			       unsigned outputChannelWidth,
			       const BinnedAxis * ebins)
{
  init(line);
   createWithUserEbins( lowerPI, 
		       nOutputChannels, 
		       outputChannelWidth,
		       ebins);
}

/* Destructor */
CalPNResponse::~CalPNResponse()
{
  PROC;
  delete _eboundsAxis; _eboundsAxis = 0;
  ENDPROC;
}

