// 
// Module: ConcreteRmfDataServer
// Author: Hassan Siddiqui
//
// Description: Data pool which is used during arf generation
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: ConcreteRmfDataServer.h,v 1.16 2000/11/08 15:46:59 hsiddiqu Exp $

#ifndef ConcreteRmfDataServer_H
#define ConcreteRmfDataServer_H

/* General classes */

/* SAS-specific classes */
#include "Tracer.h"

/* Local classes */
#include "RmfDataServer.h"
#include "GenericResponse.h"
#include "ResponseCorrector.h"
#include "PhotonDistribution.h"

/*******************************
 *
 * class ConcreteRmfDataServer
 *
 * Data pool which is used during rmf generation
 *
 ********************************/

class ConcreteRmfDataServer : public RmfDataServer
{
public:

  /* Constructors */ 
  ConcreteRmfDataServer( const string& instrument,
			 unsigned      tlmin,
			 unsigned      tlmax,
			 unsigned      detchans,
			 unsigned      binfactor,
			 unsigned      offset,
			 double        energyLow,
			 double        energyHigh,
			 unsigned      nEnergyBins,
			 bool          withenergyranges,
			 unsigned      line,
			 const string& submode, 
			 const string& format // Fixed or variable
			 );

  /* Destructors */
   ~ConcreteRmfDataServer();

  /* Accessors */
  MatrixColumn             *  matrixColumn( Table * table,
					    const vector<unsigned long>& sizeVect ) const;
  Xmm::Instrument            instrumentID()      const;   
  const string               instrument()        const; 
  const PhotonDistribution * photonDistibution() const; 
  const GenericResponse    * response()          const; 
  const ResponseCorrector  * responseCorrector() const; 
  const Frame              * frame()             const;  

  /* Spectrum-related properties */
  unsigned                   tlmin()             const;
  unsigned                   tlmax()             const;

private:

  GenericResponse    * _response; /* Rebinned response */
  //  GenericResponse    * _response_in; /* Actual response */
  PhotonDistribution * _photonDistribution;
  Frame              * _frame;
  ResponseCorrector  * _responseCorrector;

  string              _instrument;
  Xmm::Instrument     _instrumentID;

  unsigned           _tlmin;
  unsigned           _tlmax;

  bool               _fixedlength; // Fixed or Variable length vector column

  BinnedAxis        * _ebins;
  bool                _withebins;

};

#endif
